@@ -22,7 +22,7 @@
 #define KODE_LICENSE_H
 
 #include <tqstring.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace KODE {
 
