@@ -17,7 +17,7 @@
 #ifndef __KMIME_BOOLFLAGS_H__
 #define __KMIME_BOOLFLAGS_H__
 
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 /** This class stores boolean values in single bytes.
     It provides a similar functionality as TQBitArray
