@@ -16,7 +16,7 @@
 #define __KMIME_CHARFREQ_H__
 
 #include <tqcstring.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 #undef None
 
 namespace KMime {
